==> graphql-web-lite-16.6.0-3.tgz: package/validation/rules/UniqueFieldDefinitionNamesRule.js <==
var type_definition = require("../../type/definition.js");

var shared = require("../../shared.js");

function hasField(type, fieldName) {
  if (type_definition.isObjectType(type) || type_definition.isInterfaceType(type) || type_definition.isInputObjectType(type)) {
    return null != type.getFields()[fieldName];
  }
  return !1;
}

exports.UniqueFieldDefinitionNamesRule = function UniqueFieldDefinitionNamesRule(context) {
  const schema = context.getSchema();
  const existingTypeMap = schema ? schema.getTypeMap() : Object.create(null);
  const knownFieldNames = Object.create(null);
  return {
    InputObjectTypeDefinition: checkFieldUniqueness,
    InputObjectTypeExtension: checkFieldUniqueness,
    InterfaceTypeDefinition: checkFieldUniqueness,
    InterfaceTypeExtension: checkFieldUniqueness,
    ObjectTypeDefinition: checkFieldUniqueness,
    ObjectTypeExtension: checkFieldUniqueness
  };
  function checkFieldUniqueness(node) {
    var _node$fields;
    const typeName = node.name.value;
    if (!knownFieldNames[typeName]) {
      knownFieldNames[typeName] = Object.create(null);
    }
    const fieldNodes = null !== (_node$fields = node.fields) && void 0 !== _node$fields ? _node$fields : [];
    const fieldNames = knownFieldNames[typeName];
    for (const fieldDef of fieldNodes) {
      const fieldName = fieldDef.name.value;
      if (hasField(existingTypeMap[typeName], fieldName)) {
        context.reportError(new shared.GraphQLError(`Field "${typeName}.${fieldName}" already exists in the schema. It cannot also be defined in this type extension.`, {
          nodes: fieldDef.name
        }));
      } else if (fieldNames[fieldName]) {
        context.reportError(new shared.GraphQLError(`Field "${typeName}.${fieldName}" can only be defined once.`, {
          nodes: [ fieldNames[fieldName], fieldDef.name ]
        }));
      } else {
        fieldNames[fieldName] = fieldDef.name;
      }
    }
    return !1;
  }
};

==> graphql-web-lite-16.6.0-4.tgz: package/validation/rules/UniqueFieldDefinitionNamesRule.js <==
var type_definition = require("../../type/definition.js");

var graphql_web = require("@0no-co/graphql.web");

function hasField(type, fieldName) {
  if (type_definition.isObjectType(type) || type_definition.isInterfaceType(type) || type_definition.isInputObjectType(type)) {
    return null != type.getFields()[fieldName];
  }
  return !1;
}

exports.UniqueFieldDefinitionNamesRule = function UniqueFieldDefinitionNamesRule(context) {
  const schema = context.getSchema();
  const existingTypeMap = schema ? schema.getTypeMap() : Object.create(null);
  const knownFieldNames = Object.create(null);
  return {
    InputObjectTypeDefinition: checkFieldUniqueness,
    InputObjectTypeExtension: checkFieldUniqueness,
    InterfaceTypeDefinition: checkFieldUniqueness,
    InterfaceTypeExtension: checkFieldUniqueness,
    ObjectTypeDefinition: checkFieldUniqueness,
    ObjectTypeExtension: checkFieldUniqueness
  };
  function checkFieldUniqueness(node) {
    var _node$fields;
    const typeName = node.name.value;
    if (!knownFieldNames[typeName]) {
      knownFieldNames[typeName] = Object.create(null);
    }
    const fieldNodes = null !== (_node$fields = node.fields) && void 0 !== _node$fields ? _node$fields : [];
    const fieldNames = knownFieldNames[typeName];
    for (const fieldDef of fieldNodes) {
      const fieldName = fieldDef.name.value;
      if (hasField(existingTypeMap[typeName], fieldName)) {
        context.reportError(new graphql_web.GraphQLError(`Field "${typeName}.${fieldName}" already exists in the schema. It cannot also be defined in this type extension.`, {
          nodes: fieldDef.name
        }));
      } else if (fieldNames[fieldName]) {
        context.reportError(new graphql_web.GraphQLError(`Field "${typeName}.${fieldName}" can only be defined once.`, {
          nodes: [ fieldNames[fieldName], fieldDef.name ]
        }));
      } else {
        fieldNames[fieldName] = fieldDef.name;
      }
    }
    return !1;
  }
};
